==> cdktf-cdktf-provider-google_beta-3.0.1.tar.gz: package/lib/data-google-monitoring-uptime-check-ips/index.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataGoogleMonitoringUptimeCheckIpsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_monitoring_uptime_check_ips#id DataGoogleMonitoringUptimeCheckIps#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
}
export interface DataGoogleMonitoringUptimeCheckIpsUptimeCheckIps {
}
export declare function dataGoogleMonitoringUptimeCheckIpsUptimeCheckIpsToTerraform(struct?: DataGoogleMonitoringUptimeCheckIpsUptimeCheckIps): any;
export declare class DataGoogleMonitoringUptimeCheckIpsUptimeCheckIpsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataGoogleMonitoringUptimeCheckIpsUptimeCheckIps | undefined;
    set internalValue(value: DataGoogleMonitoringUptimeCheckIpsUptimeCheckIps | undefined);
    get ipAddress(): string;
    get location(): string;
    get region(): string;
}
export declare class DataGoogleMonitoringUptimeCheckIpsUptimeCheckIpsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataGoogleMonitoringUptimeCheckIpsUptimeCheckIpsOutputReference;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/d/google_monitoring_uptime_check_ips google_monitoring_uptime_check_ips}
*/
export declare class DataGoogleMonitoringUptimeCheckIps extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "google_monitoring_uptime_check_ips";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/d/google_monitoring_uptime_check_ips google_monitoring_uptime_check_ips} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataGoogleMonitoringUptimeCheckIpsConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataGoogleMonitoringUptimeCheckIpsConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _uptimeCheckIps;
    get uptimeCheckIps(): DataGoogleMonitoringUptimeCheckIpsUptimeCheckIpsList;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-google_beta-7.0.0.tar.gz: package/lib/data-google-monitoring-uptime-check-ips/index.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataGoogleMonitoringUptimeCheckIpsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_monitoring_uptime_check_ips#id DataGoogleMonitoringUptimeCheckIps#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
}
export interface DataGoogleMonitoringUptimeCheckIpsUptimeCheckIps {
}
export declare function dataGoogleMonitoringUptimeCheckIpsUptimeCheckIpsToTerraform(struct?: DataGoogleMonitoringUptimeCheckIpsUptimeCheckIps): any;
export declare class DataGoogleMonitoringUptimeCheckIpsUptimeCheckIpsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataGoogleMonitoringUptimeCheckIpsUptimeCheckIps | undefined;
    set internalValue(value: DataGoogleMonitoringUptimeCheckIpsUptimeCheckIps | undefined);
    get ipAddress(): string;
    get location(): string;
    get region(): string;
}
export declare class DataGoogleMonitoringUptimeCheckIpsUptimeCheckIpsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataGoogleMonitoringUptimeCheckIpsUptimeCheckIpsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_monitoring_uptime_check_ips google_monitoring_uptime_check_ips}
*/
export declare class DataGoogleMonitoringUptimeCheckIps extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "google_monitoring_uptime_check_ips";
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_monitoring_uptime_check_ips google_monitoring_uptime_check_ips} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataGoogleMonitoringUptimeCheckIpsConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataGoogleMonitoringUptimeCheckIpsConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _uptimeCheckIps;
    get uptimeCheckIps(): DataGoogleMonitoringUptimeCheckIpsUptimeCheckIpsList;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
